==> haskell-test-framework-smallcheck-0.2-356.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-6z9XlAV6fjN2m6GiOuh80L
key:                  test-framework-smallcheck-0.2-6z9XlAV6fjN2m6GiOuh80L
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  143847fbd38f6531ab22c27e3103b49a
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/test-framework-smallcheck-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-smallcheck
hs-libraries:         HStest-framework-smallcheck-0.2-6z9XlAV6fjN2m6GiOuh80L
depends:
    base-4.18.2.1 smallcheck-1.2.1.1-KFqvf5MX9q0F5fKZs5XDfG
    test-framework-0.8.2.2-ITHWZraIqyRCzzqSShCGFx transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-smallcheck-0.2-357-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-AhwHB5vaVgHBn8hpR9iEMd
key:                  test-framework-smallcheck-0.2-AhwHB5vaVgHBn8hpR9iEMd
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  1dceb9a41aef071fe8e0de886b23c7ba
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/test-framework-smallcheck-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-smallcheck
hs-libraries:         HStest-framework-smallcheck-0.2-AhwHB5vaVgHBn8hpR9iEMd
depends:
    base-4.18.2.1 smallcheck-1.2.1.1-1IgojUhwjusBuCDUS7RhYP
    test-framework-0.8.2.2-8fX8NEZ5OtDCOpAj0ijyRX transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
